@@ -67,7 +67,7 @@ Feature 161019991640: Added Total Free/Total Used to "-t" option.
 #endif
 #define BARLEN 35
 #define HEADERLEN 14
-#define VERSION "0.8.2"
+#define VERSION "0.8.3"
 
 
 extern char *optarg;
@@ -133,6 +133,15 @@ int main(int argc, char *argv[]) {
   } sinfo;
 
   statgrab_init();
+
+#ifdef HAVE_STATGRAB_DROP_PRIVILEGES
+  /* Drop setuid/setgid privileges. */
+  if (statgrab_drop_privileges() != 0) {
+    perror("Error. Failed to drop privileges");
+    return 1;
+  }
+#endif
+
 #endif
 #ifdef NO_GETOPT
   for (i=1;i<argc;i++) {
